@@ -129,6 +129,8 @@ empty) enumerates files and directories which are additionally installed into
 the build directory. By default, only files with the following extension are
 installed: .go, .c, .cc, .cpp, .h, .hh, hpp, .proto, .s. Starting with dh-golang
 1.31, testdata directory contents are installed by default.
+Starting with dh-golang 1.39, go.mod and go.sum are installed by default
+to support Go 1.11 modules.
 
 Example (in C<debian/rules>):
 
@@ -140,6 +142,8 @@ C<DH_GOLANG_INSTALL_ALL> (bool, default false) controls whether all files are
 installed into the build directory. By default, only files with the following
 extension are installed: .go, .c, .cc, .cpp, .h, .hh, .hpp, .proto, .s. Starting
 with dh-golang 1.31, testdata directory contents are installed by default.
+Starting with dh-golang 1.39, go.mod and go.sum are installed by default
+to support Go 1.11 modules.
 
 Example (in C<debian/rules>):
 
@@ -295,6 +299,16 @@ sub _set_gocache {
     $ENV{GOCACHE} = "off";
 }
 
+sub _set_go111module {
+    # Honor the user’s wishes if GO111MODULE was explicitly set.
+    return if defined($ENV{GO111MODULE}) && $ENV{GO111MODULE} ne '';
+
+    # Operate in "GOPATH mode" by default for "minimal module compatibility",
+    # otherwise Go >= 1.11 would attempt to check module information on-line.
+    # See https://github.com/golang/go/wiki/Modules
+    $ENV{GO111MODULE} = "off";
+}
+
 sub _link_contents {
     my ($src, $dst) = @_;
 
@@ -367,9 +381,12 @@ sub configure {
             my $name = substr($File::Find::name, 2);
             if ($install_all) {
                 # All files will be installed
-	    } elsif ((grep { $_ eq "testdata" } File::Spec->splitdir($File::Find::dir)) > 0) {
-		# The go tool treats testdata directories as special, so install
-		# their contents by default.
+            } elsif ((grep { $_ eq "testdata" } File::Spec->splitdir($File::Find::dir)) > 0) {
+                # The go tool treats testdata directories as special,
+                # so install their contents by default.
+            } elsif ($name eq 'go.mod' or $name eq 'go.sum') {
+                # The go.mod file is mandatory for Go programs which require
+                # v2+ modules.  See https://github.com/golang/go/wiki/Modules
             } else {
                 my $dot = rindex($name, ".");
                 return if $dot == -1;
@@ -457,6 +474,7 @@ sub build {
 
     $this->_set_gopath();
     $this->_set_gocache();
+    $this->_set_go111module();
     if (exists($ENV{DH_GOLANG_GO_GENERATE}) && $ENV{DH_GOLANG_GO_GENERATE} == 1) {
         $this->doit_in_builddir("go", "generate", "-v", @_, get_targets());
     }
@@ -471,6 +489,7 @@ sub test {
 
     $this->_set_gopath();
     $this->_set_gocache();
+    $this->_set_go111module();
     unshift @_, ('-p', $this->get_parallel());
     # Go 1.10 started calling “go vet” when running “go test”. This breaks tests
     # of many not-yet-fixed upstream packages, so we disable it for the time
